summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--crawl-ref/source/beam.cc4
-rw-r--r--crawl-ref/source/command.cc28
-rw-r--r--crawl-ref/source/command.h2
-rw-r--r--crawl-ref/source/decks.cc2
-rw-r--r--crawl-ref/source/directn.cc74
-rw-r--r--crawl-ref/source/directn.h34
-rw-r--r--crawl-ref/source/enum.h10
-rw-r--r--crawl-ref/source/hiscores.cc8
-rw-r--r--crawl-ref/source/initfile.cc4
-rw-r--r--crawl-ref/source/item_use.cc10
-rw-r--r--crawl-ref/source/macro.cc8
-rw-r--r--crawl-ref/source/mon-behv.cc2
-rw-r--r--crawl-ref/source/mon-cast.cc10
-rw-r--r--crawl-ref/source/mon-util.cc2
-rw-r--r--crawl-ref/source/options.h8
-rw-r--r--crawl-ref/source/ouch.cc2
-rw-r--r--crawl-ref/source/ouch.h2
-rw-r--r--crawl-ref/source/output.cc4
-rw-r--r--crawl-ref/source/spells1.cc4
-rw-r--r--crawl-ref/source/spells4.cc6
-rw-r--r--crawl-ref/source/spl-cast.cc8
-rw-r--r--crawl-ref/source/spl-cast.h10
-rw-r--r--crawl-ref/source/spl-util.cc6
-rw-r--r--crawl-ref/source/spl-util.h2
-rw-r--r--crawl-ref/source/state.cc2
-rw-r--r--crawl-ref/source/state.h4
-rw-r--r--crawl-ref/source/tilereg.cc8
-rw-r--r--crawl-ref/source/tilesdl.cc6
-rw-r--r--crawl-ref/source/wiz-item.cc2
-rw-r--r--crawl-ref/source/xom.cc2
30 files changed, 137 insertions, 137 deletions
diff --git a/crawl-ref/source/command.cc b/crawl-ref/source/command.cc
index a6a1877d52..a5935cd919 100644
--- a/crawl-ref/source/command.cc
+++ b/crawl-ref/source/command.cc
@@ -735,7 +735,7 @@ static bool _cmdhelp_textfilter(const std::string &tag)
return (false);
}
-static const char *targetting_help_1 =
+static const char *targeting_help_1 =
"<h>Examine surroundings ('<w>x</w><h>' in main):\n"
"<w>Esc</w> : cancel (also <w>Space</w>, <w>x</w>)\n"
"<w>Dir.</w>: move cursor in that direction\n"
@@ -749,13 +749,13 @@ static const char *targetting_help_1 =
"<w>_</w> : cycle through altars\n"
"<w><<</w>/<w>></w> : cycle through up/down stairs\n"
"<w>Tab</w> : cycle through shops and portals\n"
- "<w>Ctrl-F</w> : change monster targetting mode\n"
+ "<w>Ctrl-F</w> : change monster targeting mode\n"
#ifndef USE_TILE
- "<w>Ctrl-L</w> : toggle targetting via monster list\n"
+ "<w>Ctrl-L</w> : toggle targeting via monster list\n"
#endif
"<w>Ctrl-P</w> : repeat prompt\n"
" \n"
- "<h>targetting (zapping wands, casting spells, etc.):\n"
+ "<h>targeting (zapping wands, casting spells, etc.):\n"
"The keys from examine surroundings also work here.\n"
"In addition, you can use:\n"
"<w>Enter</w> : fire at target (<w>Space</w>, <w>Del</w>)\n"
@@ -767,7 +767,7 @@ static const char *targetting_help_1 =
"<w>Shift-Dir</w> : shoot straight-line beam\n"
#ifdef WIZARD
" \n"
- "<h>Wizard targetting commands:</h>\n"
+ "<h>Wizard targeting commands:</h>\n"
"<w>g</w>: give item to monster\n"
"<w>s</w>: force monster to shout or speak\n"
"<w>S</w>: make monster a summoned monster\n"
@@ -782,7 +782,7 @@ static const char *targetting_help_1 =
#endif
;
-static const char *targetting_help_2 =
+static const char *targeting_help_2 =
"<h>Firing or throwing a missile:\n"
"<w>(</w> : cycle to next suitable missile.\n"
"<w>)</w> : cycle to previous suitable missile.\n"
@@ -1996,7 +1996,7 @@ static int _show_keyhelp_menu(const std::vector<formatted_string> &lines,
"<w>F</w>. Monsters\n"
"<w>G</w>. Items\n"
"<w>H</w>. Spellcasting\n"
- "<w>I</w>. targetting\n"
+ "<w>I</w>. Targeting\n"
"<w>J</w>. Religion\n"
"<w>K</w>. Mutations\n"
"<w>L</w>. Licence, Contact, History\n"
@@ -2094,14 +2094,14 @@ void show_levelmap_help()
show_specific_help( getHelpString("level-map") );
}
-void show_targetting_help()
+void show_targeting_help()
{
column_composer cols(2, 41);
// Page size is number of lines - one line for --more-- prompt.
cols.set_pagesize(get_number_of_lines() - 1);
- cols.add_formatted(0, targetting_help_1, true, true);
- cols.add_formatted(1, targetting_help_2, true, true);
+ cols.add_formatted(0, targeting_help_1, true, true);
+ cols.add_formatted(1, targeting_help_2, true, true);
_show_keyhelp_menu(cols.formatted_lines(), false, true);
}
void show_interlevel_travel_branch_help()
@@ -2473,7 +2473,7 @@ static void _add_formatted_keyhelp(column_composer &cols)
std::string text =
"Many commands have context sensitive "
"help, among them <w>%</w>, <w>%</w>, <w>%</w> (or any "
- "form of targetting), <w>%</w>, and <w>%</w>.\n"
+ "form of targeting), <w>%</w>, and <w>%</w>.\n"
"You can read descriptions of your "
"current spells (<w>%</w>), skills (<w>%?</w>) and "
"abilities (<w>%!</w>).";
@@ -2579,7 +2579,7 @@ static void _add_formatted_tutorial_help(column_composer &cols)
cols.add_formatted(
1,
- "<h>Targetting (for spells and missiles)\n"
+ "<h>Targeting (for spells and missiles)\n"
"Use <w>+</w> (or <w>=</w>) and <w>-</w> to cycle between\n"
"hostile monsters. <w>Enter</w> or <w>.</w> or <w>Del</w>\n"
"all fire at the selected target.\n"
@@ -2696,8 +2696,8 @@ int list_wizard_commands(bool do_redraw_screen)
"<w>O</w> : measure exploration time\n"
"<w>Ctrl-t</w> : enter in-game Lua interpreter\n"
"\n"
- "<yellow>Wizard targetting commands</yellow>\n"
- "<w>x?</w> : list targetted commands\n"
+ "<yellow>Wizard targeting commands</yellow>\n"
+ "<w>x?</w> : list targeted commands\n"
"\n"
"<w>?</w> : list wizard commands\n",
true, true);
diff --git a/crawl-ref/source/command.h b/crawl-ref/source/command.h
index eb5dafbc16..ed59e92246 100644
--- a/crawl-ref/source/command.h
+++ b/crawl-ref/source/command.h
@@ -18,7 +18,7 @@ void list_jewellery();
void swap_inv_slots(int slot1, int slot2, bool verbose);
void show_levelmap_help();
-void show_targetting_help();
+void show_targeting_help();
void show_interlevel_travel_branch_help();
void show_interlevel_travel_depth_help();
void show_stash_search_help();
diff --git a/crawl-ref/source/decks.cc b/crawl-ref/source/decks.cc
index 892eac66d5..c552e8b2b5 100644
--- a/crawl-ref/source/decks.cc
+++ b/crawl-ref/source/decks.cc
@@ -2827,7 +2827,7 @@ bool card_effect(card_type which_card, deck_rarity_type rarity,
if (tell_card)
{
- // These card types will usually give this message in the targetting
+ // These card types will usually give this message in the targeting
// prompt, and the cases where they don't are handled specially.
if (which_card != CARD_VITRIOL && which_card != CARD_FLAME
&& which_card != CARD_FROST && which_card != CARD_HAMMER
diff --git a/crawl-ref/source/hiscores.cc b/crawl-ref/source/hiscores.cc
index ecad15ec44..76eba6784f 100644
--- a/crawl-ref/source/hiscores.cc
+++ b/crawl-ref/source/hiscores.cc
@@ -423,7 +423,7 @@ static const char *kill_method_names[] =
"mon", "pois", "cloud", "beam", "lava", "water",
"stupidity", "weakness", "clumsiness", "trap", "leaving", "winning",
"quitting", "draining", "starvation", "freezing", "burning",
- "wild_magic", "xom", "rotting", "targetting", "spore",
+ "wild_magic", "xom", "rotting", "targeting", "spore",
"tso_smiting", "petrification", "something",
"falling_down_stairs", "acid", "curare",
"beogh_smiting", "divine_wrath", "bounce", "reflect", "self_aimed",
@@ -1712,8 +1712,8 @@ std::string scorefile_entry::death_description(death_desc_verbosity verbosity)
desc += terse? "rotting" : "Rotted away";
break;
- case KILLED_BY_TARGETTING:
- desc += terse? "shot self" : "Killed themselves with bad targetting";
+ case KILLED_BY_TARGETING:
+ desc += terse? "shot self" : "Killed themselves with bad targeting";
needs_damage = true;
break;
@@ -1756,7 +1756,7 @@ std::string scorefile_entry::death_description(death_desc_verbosity verbosity)
case KILLED_BY_SELF_AIMED:
if (terse)
- desc += "suicidal targetting";
+ desc += "suicidal targeting";
else
{
desc += "Shot themselves with a ";
diff --git a/crawl-ref/source/initfile.cc b/crawl-ref/source/initfile.cc
index 7a6c796472..dbe3130f0a 100644
--- a/crawl-ref/source/initfile.cc
+++ b/crawl-ref/source/initfile.cc
@@ -615,7 +615,7 @@ void game_options::reset_options()
msg_max_height = std::max(10, MSG_MIN_HEIGHT);
mlist_allow_alternate_layout = false;
messages_at_top = false;
- mlist_targetting = false;
+ mlist_targeting = false;
classic_hud = false;
msg_condense_repeats = true;
msg_condense_short = true;
@@ -2434,7 +2434,7 @@ void game_options::read_option_line(const std::string &str, bool runscript)
else BOOL_OPTION(mlist_allow_alternate_layout);
else BOOL_OPTION(messages_at_top);
#ifndef USE_TILE
- else BOOL_OPTION(mlist_targetting);
+ else BOOL_OPTION(mlist_targeting);
#endif
else BOOL_OPTION(classic_hud);
else BOOL_OPTION(msg_condense_repeats);
diff --git a/crawl-ref/source/macro.cc b/crawl-ref/source/macro.cc
index fa95be243a..38ed5ff75b 100644
--- a/crawl-ref/source/macro.cc
+++ b/crawl-ref/source/macro.cc
@@ -58,7 +58,7 @@ static macromap *all_maps[] =
{
&Keymaps[KMC_DEFAULT],
&Keymaps[KMC_LEVELMAP],
- &Keymaps[KMC_TARGETTING],
+ &Keymaps[KMC_TARGETING],
&Keymaps[KMC_CONFIRM],
&Macros,
@@ -772,7 +772,7 @@ void macro_add_query( void )
else if (input == 't')
{
keymap = true;
- keymc = KMC_TARGETTING;
+ keymc = KMC_TARGETING;
}
else if (input == 'c')
{
@@ -804,7 +804,7 @@ void macro_add_query( void )
std::string prompt = make_stringf("Input %s%s trigger key: ",
keymap ? (keymc == KMC_DEFAULT ? "default " :
keymc == KMC_LEVELMAP ? "level-map " :
- keymc == KMC_TARGETTING ? "targetting " :
+ keymc == KMC_TARGETING ? "targeting " :
keymc == KMC_CONFIRM ? "confirm " :
keymc == KMC_MENU ? "menu "
: "buggy") : "",
@@ -1182,7 +1182,7 @@ KeymapContext context_for_command(command_type cmd)
return KMC_LEVELMAP;
if (cmd >= CMD_MIN_TARGET && cmd <= CMD_MAX_TARGET)
- return KMC_TARGETTING;
+ return KMC_TARGETING;
#ifdef USE_TILE
if (cmd >= CMD_MIN_DOLL && cmd <= CMD_MAX_DOLL)
diff --git a/crawl-ref/source/mon-behv.cc b/crawl-ref/source/mon-behv.cc
index 3ee21f73ca..ef97c4fc2f 100644
--- a/crawl-ref/source/mon-behv.cc
+++ b/crawl-ref/source/mon-behv.cc
@@ -132,7 +132,7 @@ void handle_behaviour(monsters *mon)
return;
}
- // Make sure monsters are not targetting the player in arena mode.
+ // Make sure monsters are not targeting the player in arena mode.
ASSERT(!(crawl_state.arena && mon->foe == MHITYOU));
if (mons_wall_shielded(mon) && cell_is_solid(mon->pos()))
diff --git a/crawl-ref/source/mon-cast.cc b/crawl-ref/source/mon-cast.cc
index e58c5cbad8..7e991e4196 100644
--- a/crawl-ref/source/mon-cast.cc
+++ b/crawl-ref/source/mon-cast.cc
@@ -925,7 +925,7 @@ bool setup_mons_cast(monsters *monster, bolt &pbolt, spell_type spell_cast,
{
pbolt.target = targ->pos();
#if DEBUG_DIAGNOSTICS
- mprf("Porkalator: targetting %s instead",
+ mprf("Porkalator: targeting %s instead",
targ->name(DESC_PLAIN).c_str());
#endif
monster_polymorph(targ, hog_type);
@@ -1660,7 +1660,7 @@ void mons_cast(monsters *monster, bolt &pbolt, spell_type spell_cast,
ASSERT(!(flags & (SPFLAG_TESTING | SPFLAG_MAPPING)));
// Targeted spells need a valid target.
- ASSERT(!(flags & SPFLAG_TARGETTING_MASK) || in_bounds(pbolt.target));
+ ASSERT(!(flags & SPFLAG_TARGETING_MASK) || in_bounds(pbolt.target));
#endif
if (do_noise)
@@ -2439,7 +2439,7 @@ void mons_cast_noise(monsters *monster, bolt &pbolt, spell_type spell_cast,
// Noise for targeted spells happens at where the spell hits,
// rather than where the spell is cast. zappy() sets up the
// noise for beams.
- noise = (flags & SPFLAG_TARGETTING_MASK)
+ noise = (flags & SPFLAG_TARGETING_MASK)
? 1 : spell_noise(actual_spell);
}
}
@@ -2453,7 +2453,7 @@ void mons_cast_noise(monsters *monster, bolt &pbolt, spell_type spell_cast,
const bool visible_beam = pbolt.type != 0 && pbolt.type != ' '
&& pbolt.name[0] != '0'
&& !pbolt.is_enchantment();
- const bool targeted = (flags & SPFLAG_TARGETTING_MASK)
+ const bool targeted = (flags & SPFLAG_TARGETING_MASK)
&& (pbolt.target != monster->pos() || visible_beam);
std::vector<std::string> key_list;
@@ -2622,7 +2622,7 @@ void mons_cast_noise(monsters *monster, bolt &pbolt, spell_type spell_cast,
else if (pbolt.target == monster->pos())
target = monster->pronoun(PRONOUN_REFLEXIVE);
// Monsters should only use targeted spells while foe == MHITNOT
- // if they're targetting themselves.
+ // if they're targeting themselves.
else if (monster->foe == MHITNOT && !monster->confused())
target = "NONEXISTENT FOE";
else if (!invalid_monster_index(monster->foe)
diff --git a/crawl-ref/source/mon-util.cc b/crawl-ref/source/mon-util.cc
index 3e1eb20906..82c8ae2f10 100644
--- a/crawl-ref/source/mon-util.cc
+++ b/crawl-ref/source/mon-util.cc
@@ -2302,7 +2302,7 @@ bool mons_should_fire(struct bolt &beam)
if (_beneficial_beam_flavour(beam.flavour))
return (_mons_should_fire_beneficial(beam));
- // Friendly monsters shouldn't be targetting you: this will happen
+ // Friendly monsters shouldn't be targeting you: this will happen
// often because the default behaviour for charmed monsters is to
// have you as a target. While foe_ratio will handle this, we
// don't want a situation where a friendly dragon breathes through
diff --git a/crawl-ref/source/ouch.cc b/crawl-ref/source/ouch.cc
index fed4d2c210..022a099a33 100644
--- a/crawl-ref/source/ouch.cc
+++ b/crawl-ref/source/ouch.cc
@@ -773,7 +773,7 @@ static void _xom_checks_damage(kill_method_type death_type,
{
if (you.religion == GOD_XOM)
{
- if (death_type == KILLED_BY_TARGETTING
+ if (death_type == KILLED_BY_TARGETING
|| death_type == KILLED_BY_BOUNCE
|| death_type == KILLED_BY_REFLECTION
|| death_type == KILLED_BY_SELF_AIMED
diff --git a/crawl-ref/source/ouch.h b/crawl-ref/source/ouch.h
index 87c545f239..f413f2fdbb 100644
--- a/crawl-ref/source/ouch.h
+++ b/crawl-ref/source/ouch.h
@@ -36,7 +36,7 @@ enum kill_method_type
KILLED_BY_WILD_MAGIC,
KILLED_BY_XOM,
KILLED_BY_ROTTING,
- KILLED_BY_TARGETTING,
+ KILLED_BY_TARGETING,
KILLED_BY_SPORE,
KILLED_BY_TSO_SMITING,
KILLED_BY_PETRIFICATION,
diff --git a/crawl-ref/source/output.cc b/crawl-ref/source/output.cc
index 215cd9a3fe..62ea4bf7ac 100644
--- a/crawl-ref/source/output.cc
+++ b/crawl-ref/source/output.cc
@@ -1243,7 +1243,7 @@ static void _print_next_monster_desc(const std::vector<monster_info>& mons,
{
int printed = 0;
- // for targetting
+ // for targeting
if (idx >= 0)
{
textcolor(WHITE);
@@ -1389,7 +1389,7 @@ int update_monster_pane()
if (i_print >= skip_lines && i_mons < (int) mons.size())
{
_print_next_monster_desc(mons, i_mons, full_info,
- crawl_state.mlist_targetting ? i_print : -1);
+ crawl_state.mlist_targeting ? i_print : -1);
}
else
cprintf("%s", blank.c_str());
diff --git a/crawl-ref/source/spells1.cc b/crawl-ref/source/spells1.cc
index a892196980..0379f72f9a 100644
--- a/crawl-ref/source/spells1.cc
+++ b/crawl-ref/source/spells1.cc
@@ -587,7 +587,7 @@ bool conjure_flame(int pow, const coord_def& where)
return (false);
}
- // Note that self-targetting is handled by SPFLAG_NOT_SELF.
+ // Note that self-targeting is handled by SPFLAG_NOT_SELF.
monsters *monster = monster_at(where);
if (monster)
{
@@ -638,7 +638,7 @@ bool stinking_cloud( int pow, bolt &beem )
beem.is_explosion = true;
beem.aux_source.clear();
- // Don't bother tracing if you're targetting yourself.
+ // Don't bother tracing if you're targeting yourself.
if (beem.target != you.pos())
{
// Fire tracer.
diff --git a/crawl-ref/source/spells4.cc b/crawl-ref/source/spells4.cc
index 56c0c3a3d2..f9c582b7c3 100644
--- a/crawl-ref/source/spells4.cc
+++ b/crawl-ref/source/spells4.cc
@@ -325,7 +325,7 @@ void cast_shatter(int pow)
}
if (damage > 0)
- ouch(damage, NON_MONSTER, KILLED_BY_TARGETTING);
+ ouch(damage, NON_MONSTER, KILLED_BY_TARGETING);
int rad = 3 + (you.skills[SK_EARTH_MAGIC] / 5);
@@ -725,7 +725,7 @@ void cast_ignite_poison(int pow)
mpr("The poison in your system burns!");
}
- ouch(damage, NON_MONSTER, KILLED_BY_TARGETTING);
+ ouch(damage, NON_MONSTER, KILLED_BY_TARGETING);
if (you.duration[DUR_POISONING] > 0)
{
@@ -1490,7 +1490,7 @@ bool cast_fragmentation(int pow, const dist& spd)
}
}
- // Mark that a monster was targetted.
+ // Mark that a monster was targeted.
beam.damage.num = 1;
// Yes, this spell does lousy damage if the monster
diff --git a/crawl-ref/source/spl-util.cc b/crawl-ref/source/spl-util.cc
index 4825e6387d..4c109c998c 100644
--- a/crawl-ref/source/spl-util.cc
+++ b/crawl-ref/source/spl-util.cc
@@ -110,7 +110,7 @@ void init_spell_descs(void)
data.title);
}
- if (data.flags & SPFLAG_TARGETTING_MASK)
+ if (data.flags & SPFLAG_TARGETING_MASK)
{
if (data.min_range <= -1 || data.max_range <= 0)
{
@@ -354,7 +354,7 @@ bool spell_harms_target(spell_type spell)
if (flags & (SPFLAG_HELPFUL | SPFLAG_NEUTRAL))
return false;
- if (flags & SPFLAG_TARGETTING_MASK)
+ if (flags & SPFLAG_TARGETING_MASK)
return true;
return false;
@@ -745,7 +745,7 @@ void apply_area_cloud( cloud_func func, const coord_def& where,
// FIXME: this should accept a direction_chooser_args directly rather
// than move the arguments into one.
bool spell_direction( dist &spelld, bolt &pbolt,
- targetting_type restrict, targ_mode_type mode,
+ targeting_type restrict, targ_mode_type mode,
int range,
bool needs_path, bool may_target_monster,
bool may_target_self, const char *target_prefix,
diff --git a/crawl-ref/source/spl-util.h b/crawl-ref/source/spl-util.h
index 284c5b679d..010f4476f5 100644
--- a/crawl-ref/source/spl-util.h
+++ b/crawl-ref/source/spl-util.h
@@ -109,7 +109,7 @@ void apply_area_cloud(cloud_func func, const coord_def& where,
std::string name = "", std::string tile = "");
bool spell_direction( dist &spelld, bolt &pbolt,
- targetting_type restrict = DIR_NONE,
+ targeting_type restrict = DIR_NONE,
targ_mode_type mode = TARG_HOSTILE,
// pbolt.range if applicable, otherwise LOS_RADIUS
int range = 0,
diff --git a/crawl-ref/source/state.cc b/crawl-ref/source/state.cc
index f541f36bd3..de3a487bfd 100644
--- a/crawl-ref/source/state.cc
+++ b/crawl-ref/source/state.cc
@@ -36,7 +36,7 @@ game_state::game_state()
prev_repetition_turn(0), cmd_repeat_started_unsafe(false),
input_line_curr(0), level_annotation_shown(false),
#ifndef USE_TILE
- mlist_targetting(false),
+ mlist_targeting(false),
#endif
darken_range(-1)
{
diff --git a/crawl-ref/source/tilesdl.cc b/crawl-ref/source/tilesdl.cc
index 6e56fa0203..0dd7585ccd 100644
--- a/crawl-ref/source/tilesdl.cc
+++ b/crawl-ref/source/tilesdl.cc
@@ -768,14 +768,14 @@ int TilesFramework::getch_ck()
int key = 0;
- // Don't update tool tips etc. in targetting mode.
+ // Don't update tool tips etc. in targeting mode.
const bool mouse_target_mode
= (mouse_control::current_mode() == MOUSE_MODE_TARGET_PATH
|| mouse_control::current_mode() == MOUSE_MODE_TARGET_DIR);
- // When moving the mouse via cursor when targetting update more often.
+ // When moving the mouse via cursor when targeting update more often.
// For beams, the beam drawing already handles this, and when not
- // targetting the normal drawing routines handle it.
+ // targeting the normal drawing routines handle it.
const unsigned int ticks_per_cursor_redraw = (mouse_target_mode ? 100 : 30);
const unsigned int ticks_per_screen_redraw = Options.tile_update_rate;
diff --git a/crawl-ref/source/wiz-item.cc b/crawl-ref/source/wiz-item.cc
index 726bf89ed2..4d8a30baf4 100644
--- a/crawl-ref/source/wiz-item.cc
+++ b/crawl-ref/source/wiz-item.cc
@@ -741,7 +741,7 @@ void wizard_unidentify_pack()
you.redraw_quiver = true;
// Forget things that nearby monsters are carrying, as well.
- // (For use with the "give monster an item" wizard targetting
+ // (For use with the "give monster an item" wizard targeting
// command.)
for (monster_iterator mon(&you.get_los()); mon; ++mon)
{
diff --git a/crawl-ref/source/xom.cc b/crawl-ref/source/xom.cc
index 0dbd32a726..83c78aa8b9 100644
--- a/crawl-ref/source/xom.cc
+++ b/crawl-ref/source/xom.cc
@@ -4131,7 +4131,7 @@ static int _death_is_worth_saving(const kill_method_type killed_by,
// Don't protect the player from these.
case KILLED_BY_SELF_AIMED:
- case KILLED_BY_TARGETTING:
+ case KILLED_BY_TARGETING:
return (false);
// Only if not caused by equipment.
diff --git a/crawl-ref/source/beam.cc b/crawl-ref/source/beam.cc
index fadf7dbb7e..958462d247 100644
--- a/crawl-ref/source/beam.cc
+++ b/crawl-ref/source/beam.cc
@@ -2011,7 +2011,7 @@ bool bolt::hit_wall()
&& !feat_is_solid(grd(target)))
{
// Okay, with all those tests passed, this is probably an instance
// of the player manually targetting something whose line of fire
// is blocked, even though its line of sight isn't blocked. Give
// a warning about this fact.
std::string prompt = "Your line of fire to ";
@@ -3595,7 +3595,7 @@ void bolt::internal_ouch(int dam)
if (aimed_at_feet && effect_known)
ouch(dam, NON_MONSTER, KILLED_BY_SELF_AIMED, name.c_str());
else
- ouch(dam, NON_MONSTER, KILLED_BY_TARGETTING);
+ ouch(dam, NON_MONSTER, KILLED_BY_TARGETING);
}
}
else if (flavour == BEAM_DISINTEGRATION || flavour == BEAM_NUKE)
@@ -2011,7 +2011,7 @@ bool bolt::hit_wall()
{
// Okay, with all those tests passed, this is probably an instance
- // of the player manually targetting something whose line of fire
+ // of the player manually targeting something whose line of fire
// is blocked, even though its line of sight isn't blocked. Give
// a warning about this fact.
diff --git a/crawl-ref/source/directn.cc b/crawl-ref/source/directn.cc
index e855296a58..c55ccde1d5 100644
--- a/crawl-ref/source/directn.cc
+++ b/crawl-ref/source/directn.cc
@@ -127,7 +127,7 @@ static char _find_square(coord_def &mfp, int direction,
bool need_path, int mode, int range,
bool wrap, int los = LOS_ANY);
-static int _targetting_cmd_to_compass( command_type command );
+static int _targeting_cmd_to_compass( command_type command );
static void _describe_oos_square(const coord_def& where);
static void _extend_move_to_edge(dist &moves);
static std::vector<std::string> _get_monster_desc_vector(const monsters *mon);
@@ -243,7 +243,7 @@ bool direction_chooser::choose_compass()
break;
}
- const int i = _targetting_cmd_to_compass(key_command);
+ const int i = _targeting_cmd_to_compass(key_command);
if (i != -1)
{
moves.delta = Compass[i];
@@ -263,7 +263,7 @@ bool direction_chooser::choose_compass()
return moves.isValid;
}
-static int _targetting_cmd_to_compass( command_type command )
+static int _targeting_cmd_to_compass( command_type command )
{
switch ( command )
{
@@ -304,15 +304,15 @@ static command_type shift_direction(command_type cmd)
}
}
-actor* direction_chooser::targetted_actor() const
+actor* direction_chooser::targeted_actor() const
{
if (target() == you.pos())
return &you;
else
- return targetted_monster();
+ return targeted_monster();
}
-monsters* direction_chooser::targetted_monster() const
+monsters* direction_chooser::targeted_monster() const
{
monsters* m = monster_at(target());
if (m && you.can_see(m) && !mons_is_unknown_mimic(m))
@@ -321,13 +321,13 @@ monsters* direction_chooser::targetted_monster() const
return NULL;
}
-std::string direction_chooser::build_targetting_hint_string() const
+std::string direction_chooser::build_targeting_hint_string() const
{
std::string hint_string;
// Hint for 'p' - previous target, and for 'f' - current cell, if
// applicable.
- const actor* f_target = targetted_actor();
+ const actor* f_target = targeted_actor();
const monsters* p_target = get_current_target();
if (f_target && f_target == p_target)
@@ -363,7 +363,7 @@ void direction_chooser::print_key_hints() const
}
else
{
- const std::string hint_string = build_targetting_hint_string();
+ const std::string hint_string = build_targeting_hint_string();
switch (restricts)
{
case DIR_NONE:
@@ -462,7 +462,7 @@ static bool _is_target_in_range(const coord_def& where, int range)
return (range == -1 || grid_distance(you.pos(), where) <= range);
}
-targetting_behaviour direction_chooser::stock_behaviour;
+targeting_behaviour direction_chooser::stock_behaviour;
void direction(dist &moves, const direction_chooser_args& args)
{
@@ -506,7 +506,7 @@ direction_chooser::direction_chooser(dist& moves_,
target_unshifted = Options.target_unshifted_dirs;
}
// We handle targetting for repeating commands and re-doing the
// previous command differently (i.e., not just letting the keys
// stuffed into the macro buffer replay as-is) because if the player
// targeted a monster using the movement keys and the monster then
@@ -982,7 +982,7 @@ void full_describe_view()
//
// isValid a valid target or direction was chosen
// isCancel player hit 'escape'
// isTarget targetting was used
// choseRay player wants a specific ray
// ray ...this one
// isEndpoint player wants the ray to stop on the dime
@@ -1143,14 +1143,14 @@ void _init_mlist()
if (full_info != -1)
{
_fill_monster_list(full_info);
- crawl_state.mlist_targetting = true;
+ crawl_state.mlist_targeting = true;
}
else
- crawl_state.mlist_targetting = false;
+ crawl_state.mlist_targeting = false;
}
#endif
// Find a good square to start targetting from.
coord_def direction_chooser::find_default_target() const
{
coord_def result = you.pos();
@@ -1354,14 +1354,14 @@ bool direction_chooser::handle_signals()
moves.isValid = false;
moves.isCancel = true;
- mpr("Targetting interrupted by HUP signal.", MSGCH_ERROR);
+ mpr("Targeting interrupted by HUP signal.", MSGCH_ERROR);
return true;
}
#endif
return false;
}
// Print out the initial prompt when targetting starts.
// Prompts might get scrolled off if you have too few lines available;
// we'll live with that.
void direction_chooser::show_initial_prompt()
@@ -1539,7 +1539,7 @@ void direction_chooser::reinitialize_move_flags()
moves.choseRay = false;
}
// Returns true if we've completed targetting.
bool direction_chooser::select_compass_direction(const coord_def& delta)
{
if (restricts != DIR_TARGET)
@@ -1608,7 +1608,7 @@ bool direction_chooser::looking_at_you() const
void direction_chooser::handle_movement_key(command_type key_command,
bool* loop_done)
{
- const int compass_idx = _targetting_cmd_to_compass(key_command);
+ const int compass_idx = _targeting_cmd_to_compass(key_command);
if (compass_idx != -1)
{
const coord_def& delta = Compass[compass_idx];
@@ -1696,7 +1696,7 @@ void direction_chooser::handle_wizard_command(command_type key_command,
void direction_chooser::do_redraws()
{
// Check if our targetting behaviour forces a redraw.
if (behaviour->should_redraw())
{
need_all_redraw = true;
@@ -1787,16 +1787,16 @@ void direction_chooser::describe_target()
void direction_chooser::show_help()
{
- show_targetting_help();
+ show_targeting_help();
redraw_screen();
mesclr(true);
need_all_redraw = true;
}
-void direction_chooser::cycle_targetting_mode()
+void direction_chooser::cycle_targeting_mode()
{
mode = static_cast<targ_mode_type>((mode + 1) % TARG_NUM_MODES);
- mprf("Targetting mode is now: %s", _targ_mode_name(mode).c_str());
+ mprf("Targeting mode is now: %s", _targ_mode_name(mode).c_str());
}
// Return false if we should continue looping, true if we're done.
@@ -1819,10 +1819,10 @@ bool direction_chooser::do_main_loop()
#ifndef USE_TILE
case CMD_TARGET_TOGGLE_MLIST:
- if (!crawl_state.mlist_targetting)
+ if (!crawl_state.mlist_targeting)
_init_mlist();
else
- crawl_state.mlist_targetting = false;
+ crawl_state.mlist_targeting = false;
break;
#endif
@@ -1835,7 +1835,7 @@ bool direction_chooser::do_main_loop()
case CMD_TARGET_FIND_UPSTAIR: feature_cycle_forward('<'); break;
case CMD_TARGET_FIND_DOWNSTAIR: feature_cycle_forward('>'); break;
- case CMD_TARGET_CYCLE_TARGET_MODE: cycle_targetting_mode(); break;
+ case CMD_TARGET_CYCLE_TARGET_MODE: cycle_targeting_mode(); break;
case CMD_TARGET_MAYBE_PREV_TARGET:
loop_done = looking_at_you() ? select_previous_target()
@@ -1918,8 +1918,8 @@ void direction_chooser::finalize_moves()
bool direction_chooser::choose_direction()
{
#ifndef USE_TILE
- crawl_state.mlist_targetting = false;
- if (may_target_monster && restricts != DIR_DIR && Options.mlist_targetting)
+ crawl_state.mlist_targeting = false;
+ if (may_target_monster && restricts != DIR_DIR && Options.mlist_targeting)
_init_mlist();
#endif
@@ -3851,40 +3851,40 @@ static void _describe_cell(const coord_def& where, bool in_range)
}
///////////////////////////////////////////////////////////////////////////
-// targetting_behaviour
+// targeting_behaviour
-targetting_behaviour::targetting_behaviour(bool look_around)
+targeting_behaviour::targeting_behaviour(bool look_around)
: just_looking(look_around), compass(false)
{
}
-targetting_behaviour::~targetting_behaviour()
+targeting_behaviour::~targeting_behaviour()
{
}
-int targetting_behaviour::get_key()
+int targeting_behaviour::get_key()
{
if (!crawl_state.is_replaying_keys())
flush_input_buffer(FLUSH_BEFORE_COMMAND);
msgwin_got_input();
- return unmangle_direction_keys(getchm(KMC_TARGETTING), KMC_TARGETTING,
+ return unmangle_direction_keys(getchm(KMC_TARGETING), KMC_TARGETING,
false, false);
}
-command_type targetting_behaviour::get_command(int key)
+command_type targeting_behaviour::get_command(int key)
{
if (key == -1)
key = get_key();
- command_type cmd = key_to_command(key, KMC_TARGETTING);
+ command_type cmd = key_to_command(key, KMC_TARGETING);
if (cmd >= CMD_MIN_TARGET && cmd < CMD_TARGET_CYCLE_TARGET_MODE)
return (cmd);
#ifndef USE_TILE
- // Overrides the movement keys while mlist_targetting is active.
- if (crawl_state.mlist_targetting && islower(key))
+ // Overrides the movement keys while mlist_targeting is active.
+ if (crawl_state.mlist_targeting && islower(key))
return static_cast<command_type>(CMD_TARGET_CYCLE_MLIST + (key - 'a'));
#endif
@@ -506,7 +506,7 @@ direction_chooser::direction_chooser(dist& moves_,
target_unshifted = Options.target_unshifted_dirs;
}
-// We handle targetting for repeating commands and re-doing the
+// We handle targeting for repeating commands and re-doing the
// previous command differently (i.e., not just letting the keys
// stuffed into the macro buffer replay as-is) because if the player
@@ -982,7 +982,7 @@ void full_describe_view()
// isValid a valid target or direction was chosen
// isCancel player hit 'escape'
-// isTarget targetting was used
+// isTarget targeting was used
// choseRay player wants a specific ray
// ray ...this one
@@ -1143,14 +1143,14 @@ void _init_mlist()
}
#endif
-// Find a good square to start targetting from.
+// Find a good square to start targeting from.
coord_def direction_chooser::find_default_target() const
{
@@ -1354,14 +1354,14 @@ bool direction_chooser::handle_signals()
return false;
}
-// Print out the initial prompt when targetting starts.
+// Print out the initial prompt when targeting starts.
// Prompts might get scrolled off if you have too few lines available;
// we'll live with that.
@@ -1539,7 +1539,7 @@ void direction_chooser::reinitialize_move_flags()
moves.choseRay = false;
}
-// Returns true if we've completed targetting.
+// Returns true if we've completed targeting.
bool direction_chooser::select_compass_direction(const coord_def& delta)
{
@@ -1696,7 +1696,7 @@ void direction_chooser::handle_wizard_command(command_type key_command,
void direction_chooser::do_redraws()
{
- // Check if our targetting behaviour forces a redraw.
+ // Check if our targeting behaviour forces a redraw.
if (behaviour->should_redraw())
{
diff --git a/crawl-ref/source/directn.h b/crawl-ref/source/directn.h
index 717d3d7e9c..097124dd63 100644
--- a/crawl-ref/source/directn.h
+++ b/crawl-ref/source/directn.h
@@ -22,11 +22,11 @@ public:
};
// An object that modifies the behaviour of the direction prompt.
-class targetting_behaviour
+class targeting_behaviour
{
public:
- targetting_behaviour(bool just_looking = false);
- virtual ~targetting_behaviour();
+ targeting_behaviour(bool just_looking = false);
+ virtual ~targeting_behaviour();
// Returns a keystroke for the prompt.
virtual int get_key();
@@ -68,7 +68,7 @@ public:
struct direction_chooser_args
{
- targetting_type restricts;
+ targeting_type restricts;
targ_mode_type mode;
int range;
bool just_looking;
@@ -77,7 +77,7 @@ struct direction_chooser_args
bool may_target_self;
const char *target_prefix;
std::string top_prompt;
- targetting_behaviour *behaviour;
+ targeting_behaviour *behaviour;
bool cancel_at_self;
direction_chooser_args() :
@@ -105,7 +105,7 @@ private:
bool do_main_loop();
// Return the location where targetting should start.
coord_def find_default_target() const;
void handle_mlist_cycle_command(command_type key_command);
@@ -135,7 +135,7 @@ private:
bool select_compass_direction(const coord_def& delta);
bool select_previous_target();
// Return true if we need to abort targetting due to a signal.
bool handle_signals();
void reinitialize_move_flags();
@@ -144,17 +144,17 @@ private:
const coord_def& target() const;
void set_target(const coord_def& new_target);
- std::string build_targetting_hint_string() const;
+ std::string build_targeting_hint_string() const;
- actor* targetted_actor() const;
- monsters* targetted_monster() const;
+ actor* targeted_actor() const;
+ monsters* targeted_monster() const;
// Functions which print things to the user.
// Each one is commented with a sample output.
// Whatever the caller defines. Typically something like:
// Casting: Venom Bolt.
- // Can be modified by the targetting_behaviour.
+ // Can be modified by the targeting_behaviour.
void print_top_prompt() const;
// Press: ? - help, Shift-Dir - straight line, t - giant bat
@@ -195,7 +195,7 @@ private:
// pointer is in bounds.
bool tiles_update_target();
// Display the prompt when beginning targetting.
void show_initial_prompt();
void toggle_beam();
@@ -211,14 +211,14 @@ private:
// Whether the current target is valid.
bool move_is_ok() const;
- void cycle_targetting_mode();
+ void cycle_targeting_mode();
void describe_target();
void show_help();
// Parameters.
dist& moves; // Output.
- targetting_type restricts; // What kind of target do we want?
+ targeting_type restricts; // What kind of target do we want?
targ_mode_type mode; // Hostiles or friendlies?
int range; // Max range to consider
bool just_looking;
@@ -227,8 +227,8 @@ private:
bool may_target_self; // ?? XXX Used only for _init_mlist() currently
const char *target_prefix; // A string displayed before describing target
std::string top_prompt; // Shown at the top of the message window
- targetting_behaviour *behaviour; // Can be NULL for default
- bool cancel_at_self; // Disallow self-targetting?
+ targeting_behaviour *behaviour; // Can be NULL for default
+ bool cancel_at_self; // Disallow self-targeting?
// Internal data.
ray_def beam; // The (possibly invalid) beam.
@@ -246,7 +246,7 @@ private:
bool target_unshifted; // Do unshifted direction keys fire?
// Default behaviour, saved across instances.
- static targetting_behaviour stock_behaviour;
+ static targeting_behaviour stock_behaviour;
};
@@ -105,7 +105,7 @@ private:
bool do_main_loop();
- // Return the location where targetting should start.
+ // Return the location where targeting should start.
coord_def find_default_target() const;
void handle_mlist_cycle_command(command_type key_command);
@@ -135,7 +135,7 @@ private:
bool select_compass_direction(const coord_def& delta);
bool select_previous_target();
- // Return true if we need to abort targetting due to a signal.
+ // Return true if we need to abort targeting due to a signal.
bool handle_signals();
void reinitialize_move_flags();
@@ -195,7 +195,7 @@ private:
// pointer is in bounds.
bool tiles_update_target();
- // Display the prompt when beginning targetting.
+ // Display the prompt when beginning targeting.
void show_initial_prompt();
void toggle_beam();
diff --git a/crawl-ref/source/enum.h b/crawl-ref/source/enum.h
index 9e98750eeb..b1de2bab9a 100644
--- a/crawl-ref/source/enum.h
+++ b/crawl-ref/source/enum.h
@@ -624,7 +624,7 @@ enum command_type
CMD_MAX_OVERMAP = CMD_MAP_EXIT_MAP,
- // targetting commands
+ // targeting commands
CMD_TARGET_DOWN_LEFT,
CMD_MIN_TARGET = CMD_TARGET_DOWN_LEFT,
CMD_TARGET_DOWN,
@@ -1481,7 +1481,7 @@ enum KeymapContext
{
KMC_DEFAULT, // For no-arg getchm(), must be zero.
KMC_LEVELMAP, // When in the 'X' level map
- KMC_TARGETTING, // Only during 'x' and other targetting modes
+ KMC_TARGETING, // Only during 'x' and other targeting modes
KMC_CONFIRM, // When being asked y/n/q questions
KMC_MENU, // For menus
#ifdef USE_TILE
@@ -1617,7 +1617,7 @@ enum targ_mode_type
TARG_FRIEND,
TARG_HOSTILE,
TARG_HOSTILE_SUBMERGED, // Target hostiles including submerged ones
- TARG_EVOLVABLE_PLANTS, // Targetting mode for Fedhas' evolution
+ TARG_EVOLVABLE_PLANTS, // Targeting mode for Fedhas' evolution
TARG_NUM_MODES
};
@@ -2960,12 +2960,12 @@ enum stat_type
STAT_RANDOM = 255 // leave at 255, added for increase_stats() handling {dlb}
};
-enum targetting_type
+enum targeting_type
{
DIR_NONE,
DIR_TARGET,
DIR_DIR,
- DIR_TARGET_OBJECT // New as of 27-August-2009, for item-targetting spells
+ DIR_TARGET_OBJECT // New as of 27-August-2009, for item-targeting spells
};
enum torment_source_type
diff --git a/crawl-ref/source/item_use.cc b/crawl-ref/source/item_use.cc
index 16aac85993..9efe63ff88 100644
--- a/crawl-ref/source/item_use.cc
+++ b/crawl-ref/source/item_use.cc
@@ -1231,7 +1231,7 @@ int get_next_fire_item(int current, int direction)
return fire_order[0];
}
-class fire_target_behaviour : public targetting_behaviour
+class fire_target_behaviour : public targeting_behaviour
{
public:
fire_target_behaviour()
@@ -1243,7 +1243,7 @@ public:
set_prompt();
}
- // targetting_behaviour API
+ // targeting_behaviour API
virtual command_type get_command(int key = -1);
virtual bool should_redraw() const { return need_redraw; }
virtual void clear_redraw() { need_redraw = false; }
@@ -1371,7 +1371,7 @@ void fire_target_behaviour::pick_fire_item_from_inventory()
void fire_target_behaviour::display_help()
{
- show_targetting_help();
+ show_targeting_help();
redraw_screen();
need_redraw = true;
set_prompt();
@@ -1391,7 +1391,7 @@ command_type fire_target_behaviour::get_command(int key)
case CMD_TARGET_CANCEL: chosen_ammo = false; break;
}
- return targetting_behaviour::get_command(key);
+ return targeting_behaviour::get_command(key);
}
static bool _fire_choose_item_and_target(int& slot, dist& target,
@@ -4333,7 +4333,7 @@ void zap_wand(int slot)
dist zap_wand;
int item_slot;
// Unless the character knows the type of the wand, the targetting
// system will default to enemies. -- [ds]
targ_mode_type targ_mode = TARG_HOSTILE;
@@ -4333,7 +4333,7 @@ void zap_wand(int slot)
dist zap_wand;
int item_slot;
- // Unless the character knows the type of the wand, the targetting
+ // Unless the character knows the type of the wand, the targeting
// system will default to enemies. -- [ds]
targ_mode_type targ_mode = TARG_HOSTILE;
diff --git a/crawl-ref/source/options.h b/crawl-ref/source/options.h
index ee9a0f7c4d..16c0284a1c 100644
--- a/crawl-ref/source/options.h
+++ b/crawl-ref/source/options.h
@@ -63,7 +63,7 @@ public:
int msg_max_height;
bool mlist_allow_alternate_layout;
bool messages_at_top;
- bool mlist_targetting;
+ bool mlist_targeting;
bool classic_hud;
bool msg_condense_repeats;
bool msg_condense_short;
@@ -91,7 +91,7 @@ public:
int default_friendly_pickup;
bool show_gold_turns; // Show gold and turns in HUD.
- bool show_beam; // Show targetting beam by default.
+ bool show_beam; // Show targeting beam by default.
long autopickups; // items to autopickup
bool show_inventory_weights; // show weights in inventory listings
@@ -114,7 +114,7 @@ public:
// chunks if no safe ones are present
bool easy_eat_contaminated; // like easy_eat_gourmand, but
// always active.
- bool default_target; // start targetting on a real target
+ bool default_target; // start targeting on a real target
bool autopickup_no_burden; // don't autopickup if it changes burden
bool note_all_skill_levels; // take note for all skill levels (1-27)
@@ -132,7 +132,7 @@ public:
int colour[16]; // macro fg colours to other colours
int background_colour; // select default background colour
msg_colour_type channels[NUM_MESSAGE_CHANNELS]; // msg channel colouring
- bool darken_beyond_range; // for whether targetting is out of range
+ bool darken_beyond_range; // for whether targeting is out of range
bool use_old_selection_order; // use old order of species/classes in
// selection screen
diff --git a/crawl-ref/source/spl-cast.cc b/crawl-ref/source/spl-cast.cc
index 358b245c58..75e8c67381 100644
--- a/crawl-ref/source/spl-cast.cc
+++ b/crawl-ref/source/spl-cast.cc
@@ -1121,10 +1121,10 @@ spret_type your_spells(spell_type spell, int powc, bool allow_fail)
int potion = -1;
// XXX: This handles only some of the cases where spells need
// targetting. There are others that do their own that will be
// missed by this (and thus will not properly ESC without cost
// because of it). Hopefully, those will eventually be fixed. - bwr
- if ((flags & SPFLAG_TARGETTING_MASK) && spell != SPELL_PORTAL_PROJECTILE)
+ if ((flags & SPFLAG_TARGETING_MASK) && spell != SPELL_PORTAL_PROJECTILE)
{
targ_mode_type targ =
(testbits(flags, SPFLAG_HELPFUL) ? TARG_FRIEND : TARG_HOSTILE);
@@ -1132,7 +1132,7 @@ spret_type your_spells(spell_type spell, int powc, bool allow_fail)
if (testbits(flags, SPFLAG_NEUTRAL))
targ = TARG_ANY;
- targetting_type dir =
+ targeting_type dir =
(testbits(flags, SPFLAG_TARG_OBJ) ? DIR_TARGET_OBJECT :
testbits(flags, SPFLAG_TARGET) ? DIR_TARGET :
testbits(flags, SPFLAG_GRID) ? DIR_TARGET :
@@ -1210,7 +1210,7 @@ spret_type your_spells(spell_type spell, int powc, bool allow_fail)
&& god == GOD_NO_GOD;
const int loudness = spell_noise(spell);
- const bool sound_at_caster = !(flags & SPFLAG_TARGETTING_MASK);
+ const bool sound_at_caster = !(flags & SPFLAG_TARGETING_MASK);
// Make some noise if it's actually the player casting.
// NOTE: zappy() sets up noise for beams.
@@ -1121,10 +1121,10 @@ spret_type your_spells(spell_type spell, int powc, bool allow_fail)
int potion = -1;
// XXX: This handles only some of the cases where spells need
- // targetting. There are others that do their own that will be
+ // targeting. There are others that do their own that will be
// missed by this (and thus will not properly ESC without cost
// because of it). Hopefully, those will eventually be fixed. - bwr
diff --git a/crawl-ref/source/spl-cast.h b/crawl-ref/source/spl-cast.h
index 3541f2a688..d5a31dd1e9 100644
--- a/crawl-ref/source/spl-cast.h
+++ b/crawl-ref/source/spl-cast.h
@@ -13,12 +13,12 @@
enum spflag_type
{
SPFLAG_NONE = 0x000000,
- SPFLAG_DIR_OR_TARGET = 0x000001, // use DIR_NONE targetting
- SPFLAG_TARGET = 0x000002, // use DIR_TARGET targetting
- SPFLAG_GRID = 0x000004, // use DIR_GRID targetting
- SPFLAG_DIR = 0x000008, // use DIR_DIR targetting
+ SPFLAG_DIR_OR_TARGET = 0x000001, // use DIR_NONE targeting
+ SPFLAG_TARGET = 0x000002, // use DIR_TARGET targeting
+ SPFLAG_GRID = 0x000004, // use DIR_GRID targeting
+ SPFLAG_DIR = 0x000008, // use DIR_DIR targeting
SPFLAG_TARG_OBJ = 0x000010, // use DIR_TARGET_OBJECT targ.
- SPFLAG_TARGETTING_MASK = 0x00001f, // used to test for targetting
+ SPFLAG_TARGETING_MASK = 0x00001f, // used to test for targeting
SPFLAG_HELPFUL = 0x000020, // TARG_FRIENDS used
SPFLAG_NEUTRAL = 0x000040, // TARG_ANY used
SPFLAG_NOT_SELF = 0x000080, // aborts on isMe
diff --git a/crawl-ref/source/state.h b/crawl-ref/source/state.h
index 2e835cfe83..4c487d733c 100644
--- a/crawl-ref/source/state.h
+++ b/crawl-ref/source/state.h
@@ -85,10 +85,10 @@ struct game_state
bool level_annotation_shown;
#ifndef USE_TILE
// Are we currently targetting using the mlist?
// This is global because the monster pane uses this when
// drawing.
- bool mlist_targetting;
+ bool mlist_targeting;
#endif
// Range beyond which view should be darkend, -1 == disabled.
@@ -85,10 +85,10 @@ struct game_state
bool level_annotation_shown;
#ifndef USE_TILE
- // Are we currently targetting using the mlist?
+ // Are we currently targeting using the mlist?
// This is global because the monster pane uses this when
// drawing.
diff --git a/crawl-ref/source/tilereg.cc b/crawl-ref/source/tilereg.cc
index 1a9c3dfffc..39fca2d094 100644
--- a/crawl-ref/source/tilereg.cc
+++ b/crawl-ref/source/tilereg.cc
@@ -1389,7 +1389,7 @@ static int _click_travel(const coord_def &gc, MouseEvent &event)
// to the clicked cell, whatever).
static void _add_targeting_commands(const coord_def& pos)
{
// Force targetting cursor back onto center to start off on a clean
// slate.
macro_buf_add_cmd(CMD_TARGET_CENTER);
@@ -1426,7 +1426,7 @@ static const bool _is_appropriate_spell(spell_type spell,
return (false);
const unsigned int flags = get_spell_flags(spell);
- const bool targeted = flags & SPFLAG_TARGETTING_MASK;
+ const bool targeted = flags & SPFLAG_TARGETING_MASK;
// We don't handle grid targeted spells yet.
if (flags & SPFLAG_GRID)
@@ -1581,7 +1581,7 @@ static bool _evoke_item_on_target(actor* target)
static bool _spell_in_range(spell_type spell, actor* target)
{
- if (!(get_spell_flags(spell) & SPFLAG_TARGETTING_MASK))
+ if (!(get_spell_flags(spell) & SPFLAG_TARGETING_MASK))
return (true);
int range = calc_spell_range(spell);
@@ -1653,7 +1653,7 @@ static bool _cast_spell_on_target(actor* target)
macro_buf_add_cmd(CMD_CAST_SPELL);
macro_buf_add(letter);
- if (get_spell_flags(spell) & SPFLAG_TARGETTING_MASK)
+ if (get_spell_flags(spell) & SPFLAG_TARGETING_MASK)
_add_targeting_commands(target->pos());
return (true);
}
@@ -1389,7 +1389,7 @@ static int _click_travel(const coord_def &gc, MouseEvent &event)
static void _add_targeting_commands(const coord_def& pos)
{
- // Force targetting cursor back onto center to start off on a clean
+ // Force targeting cursor back onto center to start off on a clean
// slate.
macro_buf_add_cmd(CMD_TARGET_CENTER);